## R codes of the article:

## Hitchhikers’ guide to analysing bird ringing data
## Part 3: missing data
## Harnos, A,  Csörgő, T.  & Fehérvári, P
## Ornis Hungarica 2017. 25(2): 141-156.

## ----------------Set the working directory---------------------------------------
mydirectory="/home/andrea/work/appendix"
mydirectory = "/home/andrea/work/Munka/Ornis/tutorial/part3/appendix"
setwd(mydirectory)

## ---------------Import data from a text file-------------------------------------
mydata = read.table(
   file = "data/FICHYP1.csv", #the name of the file
   sep = ";",           #the field separator character
   dec = ".",           #the character used in the file for decimal points
   header = TRUE)  #a logical value indicating whether the file 
                               #contains the names of the variables in the first line
   
## -------------import the FICHYP.csv raw dataset-----------------------------
mydata.raw = read.table("data/FICHYP.csv", sep=";",header=T, na.strings = "null")
#summarise
summary(mydata.raw$SEX)

## ------------import the FICHYP.csv with extended na.strings-------------
mydata.raw2 = read.table("data/FICHYP.csv", sep=";",header=T, 
                         na.strings = c("null", "N"))
                         #summarise
summary(mydata.raw2$SEX)

## ------------------recode values to NAs-------------------------------------------
mydata.raw$SEX = ifelse(
test = mydata$SEX == "N",
yes  = NA,
no   = as.character(mydata$SEX))

## ---------------substitute "FEJ" values to NA-----------------------------------
mydata$AGE[mydata$AGE == "FEJ"] = NA
summary(mydata$AGE)

## -----------------drop unused factor levels-------------------------------------
mydata$AGE = droplevels(mydata$AGE)
summary(mydata$AGE)

## ----------locate and counte missing values----------------------------------
x = c(81, NA, 79, 82, 83, NA, 77, 81, NA, 80)
anyNA(x)           #are there  any missing value?
#logical vector with the position of TRUE values indicating NAs
is.na(x)              
sum(is.na(x))   # nb of missing values

## ---------index of missing and nt missing values----------------------------
which(is.na(x))    #missing
which(!is.na(x))   #not missing

## -------------------subset  containing  5 variables----------------------------
mydata2 = mydata[, c("SEX", "WING", "THIRD", "MASS", "AGE")]
summary(mydata2)

## -------------------number of missing values by variables------------------
sapply(mydata2, function(x)(sum(is.na(x)))) 

## ----logical vector indicating which cases are complete-----------------
mydata2.last10 = tail(mydata2,10)
complete.cases(mydata2.last10)

## -----------------complete cases of the 10 last rows-------------------------
mydata2.last10[complete.cases(mydata2.last10),]

## ----------------incomplete cases of the 10 last rows------------------------
mydata2.last10[!complete.cases(mydata2.last10),]

## -------------mean wothout and with na.rm = T-------------------------------
mean(x) 
mean(x, na.rm = TRUE) 


## ---------------- import FICHYP_WING_missing.csv-------------------------
WING_table = read.table("data/FICHYP_WING_missing.csv", sep=";", header=T)

## ---------------descriptive statistics of WING_table-------------------------
library(RcmdrMisc)

numSummary(WING_table[,1:8], statistics=c("mean", "sd", "quantiles"), quantiles=c(0, .5, 1))
   
## --------------------------Aggregation Plot----------------------------------------
library(VIM)
aggr(mydata2, col = c("white", "grey"), prop = F, numbers = T)


## -----------------summaries of the graphs-------------------------------------
summary(aggr(mydata2))

## ----Barplot and spineplot of year with missing values in SEX-------
x <- mydata[, c("year", "SEX")]      # subset 
barMiss(x, col=c("white","grey"), only.miss = F)
spineMiss(x, col=c("white","grey") , only.miss = F)
 
## ----Barplot and spineplot of age with missing values in SEX--------
x <- mydata[, c("age", "SEX")]
barMiss(x, col=c("white","grey"),  only.miss = F)
spineMiss(x, col=c("white","grey"), only.miss = F)

## -Histogram and spinogram of MASS with missing values in WING--
x <- mydata[, c("MASS", "WING")]
barMiss(x, col=c("white","grey"), only.miss = F)
spineMiss(x, col=c("white","grey"), only.miss = F)

## -------------------create artificial missing values in WING-----------------
#Delete WING values, that were measured on birds with MASS values below the 10% quantile
MASS.WING = mydata[, c("MASS", "WING")]            #subset
limit = quantile(MASS.WING$MASS,  0.1,  na.rm = T)   #set the limit

#for loop to change MASS values to NA under the limit
for (i in 1:nrow(MASS.WING))          
{
   if (!is.na(MASS.WING$MASS[i]))
      if (MASS.WING$MASS[i] < limit)
          MASS.WING$WING[i] = NA
}

## -Histogram and spinogram of MASS with missing values in WING--
#artifical example
barMiss(MASS.WING, col=c("white","grey"), only.miss = F)
spineMiss(MASS.WING, col=c("white","grey"), only.miss = F)

## ------Mosaic plotof age and year with missing values in SEX---------
x <- mydata[, c("SEX", "age", "year")]
mosaicMiss(x, col = c("white", "grey"), plotvars = c(2, 3), highlight  = 1 , miss.labels =F )

## ----Scatterplots with Missing Data Information in the Margins------
x <- mydata[, c("MASS","WING")]
marginplot(x, col = c( grey(.5), grey(.8)))

## ----Scatterplots with Missing Data Information in the Margins-------
#artifical example
marginplot(MASS.WING, col = c( grey(.5), grey(.8)))

